@@ -34,7 +34,7 @@ if TYPE_CHECKING:
 
     from requests.auth import AuthBase
 
-    Params = Optional[  # noqa: WPS110
+    Params = Optional[
         MutableMapping[
             str,
             Union[str, List[str]],
@@ -94,7 +94,7 @@ class Token(object):
         return time() >= self.expiration_time
 
 
-class RegistrySession(object):  # noqa: WPS214
+class RegistrySession(object):
     """Container registry HTTP methods."""
 
     def __init__(self, hostname: str, auth_info: Optional[AuthInfo] = None) -> None:
@@ -135,14 +135,14 @@ class RegistrySession(object):  # noqa: WPS214
             return DOCKER_HOSTNAME
         return self._hostname
 
-    def request(  # noqa:WPS211
+    def request(  # noqa: WPS122
         self,
         method: str,
         url: str,
         *,
         scopes: Optional[Set[Scope]] = None,
-        params: Params = None,  # noqa: WPS110
-        data: Any = None,  # noqa: WPS110
+        params: Params = None,
+        data: Any = None,
         headers: Optional[Dict[str, str]] = None,
         content_type: Optional[str] = None,
         accept: Optional[Tuple[str, ...]] = None,
@@ -183,8 +183,7 @@ class RegistrySession(object):  # noqa: WPS214
         response = self._session.request(
             method,
             url,
-            # https://github.com/python/typeshed/pull/5187
-            params=params,  # type: ignore
+            params=params,
             data=data,
             headers=headers,
             auth=auth,
