@@ -44,7 +44,7 @@ class WithDigest(object):  # noqa:WPS214
 
     supported_mime_types: Optional[Tuple[str, ...]] = None
 
-    def __init__(  # noqa:WPS211
+    def __init__(
         self,
         registry: RegistryImporter,
         manifest_name: str,
@@ -70,6 +70,7 @@ class WithDigest(object):  # noqa:WPS214
         self._exists: Optional[bool] = None
         self._fd: Optional[BinaryIO] = None
         self._retrieve_mehod = 'head'
+        self.forced_digest = False
 
     def __eq__(self, other: Any) -> bool:
         """Compare.
@@ -194,7 +195,7 @@ class WithDigest(object):  # noqa:WPS214
             self._fd.close()
             self._fd = None
 
-    def read(self, n: int = -1) -> bytes:  # noqa: WPS111
+    def read(self, n: int = -1) -> bytes:  # noqa: WPS123
         """Read the cached file.
 
         Args:
@@ -231,14 +232,15 @@ class WithDigest(object):  # noqa:WPS214
             HTTPError: Error when fetching existence.
         """
         if self._exists is None:
-            try:  # noqa:WPS229
+            try:
                 self._retrieve()
                 self._exists = True
-                self.register()
             except HTTPError as err:
                 if err.response.status_code != codes['not_found']:
                     raise err
                 self._exists = False
+            if self._exists:
+                self.register()
         return self._exists
 
     def register(self) -> None:
