@@ -20,6 +20,7 @@ import os
 import re
 
 from vcr import VCR
+from vcr.matchers import body
 
 
 def _gitlabracadabra_func_path_generator(function):
@@ -50,6 +51,23 @@ def _gitlabracadabra_uri_matcher(r1, r2):
     return r1_uri == r2_uri
 
 
+def _gitlabracadabra_body_matcher(r1, r2):
+    if (
+        r1.method == 'POST' and
+        r1.method == r2.method and
+        r1.url == r2.url
+    ):
+        _, _, r1_boundary = r1.headers.get('Content-Type', '').partition('multipart/form-data; boundary=')
+        _, _, r2_boundary = r2.headers.get('Content-Type', '').partition('multipart/form-data; boundary=')
+        return (
+            r1_boundary and
+            r2_boundary and
+            r1.body.split(r1_boundary.encode()) == r2.body.split(r2_boundary.encode())
+        )
+    else:
+        return body(r1, r2)
+
+
 my_vcr = VCR(
     match_on=['method', 'gitlabracadabra_uri', 'body'],
     func_path_generator=_gitlabracadabra_func_path_generator,
@@ -57,3 +75,4 @@ my_vcr = VCR(
     inject_cassette=True,
 )
 my_vcr.register_matcher('gitlabracadabra_uri', _gitlabracadabra_uri_matcher)
+my_vcr.register_matcher('gitlabracadabra_body', _gitlabracadabra_body_matcher)
